import sys
from pathlib import Path
from typing import List

from rich.console import Console
from rich.text import Text

from .configs import ReviewConfig
from .git_diff import GitAnalysis


def create_console() -> Console:
    """Create console instance for colored output."""
    return Console()


def create_error_console() -> Console:
    return Console(stderr=True, style="bold red")


def log_review_start(config: ReviewConfig) -> None:
    console = create_console()
    """Log the start of review process with colored output."""
    console.print(
        f"ReviewLlama - Starting review of {len(config.paths)} path(s)",
        style="bold",
    )
    console.print(f"Model: [cyan]{config.ollama.model}[/cyan]")
    console.print(f"Server: [cyan]{config.ollama.base_url}[/cyan]")
    console.print()


def log_paths(paths: List[Path]) -> None:
    """Log the paths being reviewed with colored output."""
    console = create_console()
    console.print("Paths to review:")
    for path in paths:
        console.print(f"  • {path}")
    console.print()


def log_error(error: str) -> None:
    """Log error message with colored output."""
    console = create_error_console()
    console.print(f"Error: {error}")


def log_git_analysis_start(path: Path, base_branch: str) -> None:
    """Log the start of git analysis."""
    console = create_console()
    console.print(f"[dim]Analyzing git repository at:[/dim] {path}")
    console.print(f"[dim]Base branch:[/dim] {base_branch}")


def log_git_analysis_result(analysis: GitAnalysis) -> None:
    """Log the results of git analysis."""
    console = create_console()
    console.print(f"[dim]Current branch:[/dim] {analysis.current_branch}")
    console.print(f"[dim]Comparing against:[/dim] {analysis.base_branch}")
    console.print(f"[dim]Files changed:[/dim] {analysis.total_files_changed}")

    if analysis.diffs:
        console.print("\n[bold]Changed files:[/bold]")
        for diff in analysis.diffs:
            change_color = {
                "added": "green",
                "modified": "yellow",
                "deleted": "red",
            }.get(diff.change_type, "white")

            console.print(
                f"  [{change_color}]{diff.change_type.upper():>8}[/{change_color}] {diff.file_path}"
            )
    else:
        console.print("[dim]No reviewable files changed.[/dim]")

    console.print()
